pub struct MovieDetails {Show 25 fields
pub adult: bool,
pub backdrop_path: Option<String>,
pub belongs_to_collection: Option<bool>,
pub budget: i64,
pub genres: Vec<Genre>,
pub homepage: Option<String>,
pub id: i64,
pub imdb_id: Option<String>,
pub original_language: String,
pub original_title: String,
pub overview: Option<String>,
pub popularity: f64,
pub poster_path: Option<String>,
pub production_companies: Vec<ProductionCompany>,
pub production_countries: Vec<ProductionCountry>,
pub release_date: NaiveDate,
pub revenue: i64,
pub runtime: Option<i64>,
pub spoken_languages: Vec<Language>,
pub status: String,
pub tagline: Option<String>,
pub title: String,
pub video: bool,
pub vote_average: f64,
pub vote_count: i64,
}Expand description
Details on a Movies
Fields
adult: boolWhether this movie is an adult movie or not
backdrop_path: Option<String>The path the backdrop for this movie can be found at
belongs_to_collection: Option<bool>Whether this movie belongs to a collection or not
budget: i64The budget for this movie
genres: Vec<Genre>homepage: Option<String>The homepage for this Movie
id: i64The id for this movie
imdb_id: Option<String>The imdb ID for this movie
original_language: StringThe Original language this was in
original_title: StringThe original title fo this movie
overview: Option<String>An overview for this movie
popularity: f64The popularity of this movie
poster_path: Option<String>The path to the poster for this movie
production_companies: Vec<ProductionCompany>The production companies involved in making this movie
production_countries: Vec<ProductionCountry>The countries this movie was produced in
release_date: NaiveDateWhen this movie was released
revenue: i64How much this movie made in revenue
runtime: Option<i64>The total runtime of this movie in minutes
spoken_languages: Vec<Language>The languages spoken in this movie
status: StringThe current status of this movie
tagline: Option<String>The tag line or slogan for this movie
title: StringThe title of this movie
video: boolWhether this is not a movie but another type of longer video
vote_average: f64The average vote for this movie
vote_count: i64The number of votes for this movie